First attempt to capture parser/translation errors in browser.

Adds a notion of an (optional) error stream to the existing
log and emit streams. If not specified, the log stream is used.
Error messages in parser/translation are sent to this new error
stream.

In the browser compiler server, a separate error (string) stream is
created to capture errors. Method onEndCallBack returns the contents
of the error stream (if non-empty) instead of a generic error message.

BUG= https://code.google.com/p/nativeclient/issues/detail?id=4138
R=jvoung@chromium.org

Review URL: https://codereview.chromium.org/1052833003
diff --git a/src/IceGlobalContext.h b/src/IceGlobalContext.h
index 9264d43..a1fd133 100644
--- a/src/IceGlobalContext.h
+++ b/src/IceGlobalContext.h
@@ -145,14 +145,17 @@
   };
 
 public:
-  GlobalContext(Ostream *OsDump, Ostream *OsEmit, ELFStreamer *ELFStreamer,
-                const ClFlags &Flags);
+  // The dump stream is a log stream while emit is the stream code
+  // is emitted to. The error stream is strictly for logging errors.
+  GlobalContext(Ostream *OsDump, Ostream *OsEmit, Ostream *OsError,
+                ELFStreamer *ELFStreamer, const ClFlags &Flags);
   ~GlobalContext();
 
   // The dump and emit streams need to be used by only one thread at a
   // time.  This is done by exclusively reserving the streams via
   // lockStr() and unlockStr().  The OstreamLocker class can be used
   // to conveniently manage this.
   //
   // The model is that a thread grabs the stream lock, then does an
   // arbitrary amount of work during which far-away callees may grab
@@ -163,6 +166,7 @@
   void lockStr() { StrLock.lock(); }
   void unlockStr() { StrLock.unlock(); }
   Ostream &getStrDump() { return *StrDump; }
+  Ostream &getStrError() { return *StrError; }
   Ostream &getStrEmit() { return *StrEmit; }
 
   LockedPtr<ErrorCode> getErrorStatus() {
@@ -418,6 +422,7 @@
   StrLockType StrLock;
   Ostream *StrDump; // Stream for dumping / diagnostics
   Ostream *StrEmit; // Stream for code emission
+  Ostream *StrError; // Stream for logging errors.
 
   ICE_CACHELINE_BOUNDARY;
@@ -145,14 +145,17 @@
   ~GlobalContext();
 
-  // The dump and emit streams need to be used by only one thread at a
-  // time.  This is done by exclusively reserving the streams via
-  // lockStr() and unlockStr().  The OstreamLocker class can be used
-  // to conveniently manage this.
+  //
+  // The dump, error, and emit streams need to be used by only one
+  // thread at a time.  This is done by exclusively reserving the
+  // streams via lockStr() and unlockStr().  The OstreamLocker class
+  // can be used to conveniently manage this.
   //
   // The model is that a thread grabs the stream lock, then does an